@@ -7,9 +7,12 @@ class BaseTestCase(unittest.TestCase):
     @classmethod
     def setUpClass(cls):
         # jarDependencies = glob.glob("/opt/docker/lib/*.jar")
-        cls.spark = SparkSession.builder.master("local").appName("init") \
-            .config("spark.sql.legacy.allowUntypedScalaUDF", "true") \
+        cls.spark = (
+            SparkSession.builder.master("local")
+            .appName("init")
+            .config("spark.sql.legacy.allowUntypedScalaUDF", "true")
             .getOrCreate()
+        )
         cls.maxUnequalRowsToShow = 5
 
     def setup(self):
