@@ -16,7 +16,11 @@ def readResource(path: str) -> str:
 def defaultForDatatype(type: DataType):
     if isinstance(type, StringType):
         return ""
-    elif isinstance(type, IntegerType) or isinstance(type, ShortType) or isinstance(type, LongType):
+    elif (
+        isinstance(type, IntegerType)
+        or isinstance(type, ShortType)
+        or isinstance(type, LongType)
+    ):
         return 0
     elif isinstance(type, ByteType):
         return 0
@@ -48,20 +52,30 @@ def isNull(value):
 def convertStringValueToDatatype(dataType: DataType, value: str):
     if isinstance(dataType, StringType):
         newValue = value
-    elif isinstance(dataType, IntegerType) or isinstance(dataType, ShortType) or isinstance(dataType, LongType):
+    elif (
+        isinstance(dataType, IntegerType)
+        or isinstance(dataType, ShortType)
+        or isinstance(dataType, LongType)
+    ):
         newValue = 0 if isNull(value) else int(value)
     elif isinstance(dataType, ByteType):
-        newValue = 0 if isNull(value) else str.encode(value)
+        newValue = 0 if isNull(value) else int(value)
     elif isinstance(dataType, FloatType) or isinstance(dataType, DoubleType):
         newValue = 0.0 if isNull(value) else float(value)
     elif isinstance(dataType, BinaryType):
-        newValue = bytearray(0) if isNull(value) else bytearray(value)
+        newValue = bytearray(0) if isNull(value) else bytearray(value.encode("utf-8"))
     elif isinstance(dataType, BooleanType):
         newValue = False if isNull(value) else (value == "true")
     elif isinstance(dataType, DateType):
-        newValue = datetime.now() if isNull(value) else datetime.strptime(value, '%Y-%m-%d')
+        newValue = (
+            datetime.now() if isNull(value) else datetime.strptime(value, "%Y-%m-%d")
+        )
     elif isinstance(dataType, TimestampType):
-        newValue = datetime.now() if isNull(value) else datetime.strptime(value, '%Y-%m-%dT%H:%M:%S.%f%z')
+        newValue = (
+            datetime.now()
+            if isNull(value)
+            else datetime.strptime(value, "%Y-%m-%dT%H:%M:%S.%f%z")
+        )
     elif isinstance(dataType, DecimalType):
         newValue = Decimal(0) if isNull(value) else Decimal(value)
     else:
@@ -76,12 +90,16 @@ def createDF(spark, columns, values, schema, typeMap, port) -> DataFrame:
     missingValues = list(map(lambda c: defaults[c], missingColumns))
     allValues = list(map(lambda row: row + missingValues, values))
 
-    reorderedSchema = StructType(list(map(lambda column: StructField(column, typeMap[column]), allColumns)))
+    reorderedSchema = StructType(
+        list(map(lambda column: StructField(column, typeMap[column]), allColumns))
+    )
     df = spark.createDataFrame(allValues, reorderedSchema)
     return df
 
 
-def createDfFromResourceFiles(spark: SparkSession, schemaDefinitionPath: str, dataPath: str, port: str) -> DataFrame:
+def createDfFromResourceFiles(
+    spark: SparkSession, schemaDefinitionPath: str, dataPath: str, port: str
+) -> DataFrame:
     schemaJson = json.loads(readResource(schemaDefinitionPath))
     schema = StructType.fromJson(schemaJson)
 
@@ -123,7 +141,9 @@ def postProcess(origDf: DataFrame) -> DataFrame:
     return df.sql_ctx.createDataFrame(df.rdd, df.schema)
 
 
-def assertDFEquals(expectedUnsorted: DataFrame, resultUnsorted: DataFrame, maxUnequalRowsToShow: int) -> str:
+def assertDFEquals(
+    expectedUnsorted: DataFrame, resultUnsorted: DataFrame, maxUnequalRowsToShow: int
+) -> str:
     def _sort(df: DataFrame):
         if len(df.columns) == 0:
             return df
@@ -136,13 +156,17 @@ def assertDFEquals(expectedUnsorted: DataFrame, resultUnsorted: DataFrame, maxUn
         expectedTypes = fetchTypes(dfExpected)
         actualTypes = fetchTypes(dfActual)
         if expectedTypes != actualTypes:
-            raise Exception("Types NOT equal! " + str(expectedTypes) + " != " + str(actualTypes))
+            raise Exception(
+                "Types NOT equal! " + str(expectedTypes) + " != " + str(actualTypes)
+            )
 
     def _assertEqualsCount(dfExpected: DataFrame, dfActual: DataFrame):
         dfExpectedCount = dfExpected.rdd.count()
         dfActualCount = dfActual.rdd.count()
         if dfExpectedCount != dfActualCount:
-            raise Exception(f"Length not Equal.\n{str(dfExpectedCount)} vs {dfActualCount}")
+            raise Exception(
+                f"Length not Equal.\n{str(dfExpectedCount)} vs {dfActualCount}"
+            )
 
     def _assertEqualsValues(dfExpected: DataFrame, dfActual: DataFrame):
         expectedVal = dfExpected.rdd.zipWithIndex().map(lambda x: (x[1], x[0]))
@@ -152,7 +176,10 @@ def assertDFEquals(expectedUnsorted: DataFrame, resultUnsorted: DataFrame, maxUn
         unequalRDD = joined.filter(lambda x: (not rowEquals(x[1][0], x[1][1])))
 
         if len(unequalRDD.take(maxUnequalRowsToShow)) != 0:
-            raise Exception("Expected != Actual\nMismatch: " + str(unequalRDD.take(maxUnequalRowsToShow)))
+            raise Exception(
+                "Expected != Actual\nMismatch: "
+                + str(unequalRDD.take(maxUnequalRowsToShow))
+            )
 
     expected = _sort(postProcess(expectedUnsorted))
     result = _sort(postProcess(resultUnsorted))
@@ -175,7 +202,9 @@ def assertDFEquals(expectedUnsorted: DataFrame, resultUnsorted: DataFrame, maxUn
 def assertPredicates(port: str, df: DataFrame, predicates):
     for (pred, name) in predicates:
         if df.filter(pred).count() != df.count():
-            raise Exception(f"Predicate {name} [[`{pred}`]] not universally true for port {port}")
+            raise Exception(
+                f"Predicate {name} [[`{pred}`]] not universally true for port {port}"
+            )
 
 
 def readData(spark: SparkSession, schema: StructType, path: str) -> DataFrame:
@@ -187,7 +216,9 @@ def readData(spark: SparkSession, schema: StructType, path: str) -> DataFrame:
     for row in jsonData:
         newRow = []
         for idx, element in enumerate(row):
-            newElement = convertStringValueToDatatype(schema.fields[idx].dataType, element)
+            newElement = convertStringValueToDatatype(
+                schema.fields[idx].dataType, element
+            )
             newRow.append(newElement)
         data.append(newRow)
     df = spark.createDataFrame(data, schema)
@@ -195,14 +226,19 @@ def readData(spark: SparkSession, schema: StructType, path: str) -> DataFrame:
     return df
 
 
-def writeData(pathPrefix: str, fileName: str, df: DataFrame, separator: str, maxRows: int = 100):
+def writeData(
+    pathPrefix: str, fileName: str, df: DataFrame, separator: str, maxRows: int = 100
+):
     from pathlib import Path
+
     Path(pathPrefix).mkdir(parents=True, exist_ok=True)
     file = open(f"{pathPrefix}/{fileName}", "w")
     headers = separator.join(df.schema.fieldNames()) + "\n"
     for row in df.rdd.collect():
         print(row)
-    fields = "\n".join(list(map(lambda row: separator.join(list(map(str, row))), df.take(maxRows))))
+    fields = "\n".join(
+        list(map(lambda row: separator.join(list(map(str, row))), df.take(maxRows)))
+    )
     content = headers + fields
     file.write(content)
     file.close()
