@@ -24,6 +24,8 @@ def initializeUDFBase(spark):
 
 
 def rest_api(*cols):
-    _cols = udfConfig.sparkSession.sparkContext._jvm.PythonUtils.toList([item._jc for item in list(cols)])
+    _cols = udfConfig.sparkSession.sparkContext._jvm.PythonUtils.toList(
+        [item._jc for item in list(cols)]
+    )
     rest_api_response = udfConfig.UDFUtils.rest_api(_cols)
     return 1
